# Sources

There are currently scrapers for 35 of America's 56 states and territories.

| State | Docs | Authors | Tags |
| :---- | :--: | :------ | :--- |
|[Alabama](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/al.py)|[📃](scrapers/al.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Alaska](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ak.py)||[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Arizona](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/az.py)|[📃](scrapers/az.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[California](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ca.py)|[📃](scrapers/ca.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel, html, pdf|
|[Connecticut](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ct.py)||[Dilcia19](https://github.com/Dilcia19), [stucka](https://github.com/stucka), [zstumgoren](https://github.com/zstumgoren)|html|
|[Delaware](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/de.py)|[📃](scrapers/de.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Florida](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/fl.py)||[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|html, pdf|
|[Georgia](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ga.py)||[chriszs](https://github.com/chriszs)|html|
|[Idaho](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/id.py)||[chriszs](https://github.com/chriszs)|pdf|
|[Illinois](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/il.py)||[chriszs](https://github.com/chriszs)|excel, html|
|[Indiana](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/in.py)|[📃](scrapers/in.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Iowa](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ia.py)|[📃](scrapers/ia.md)|[Dilcia19](https://github.com/Dilcia19), [palewire](https://github.com/palewire), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|excel, html|
|[Kansas](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ks.py)|[📃](scrapers/ks.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Kentucky](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ky.py)||[palewire](https://github.com/palewire)|excel|
|[Louisiana](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/la.py)||[chriszs](https://github.com/chriszs)|html, pdf|
|[Maine](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/me.py)|[📃](scrapers/me.md)|[zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Maryland](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/md.py)|[📃](scrapers/md.md)|[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|html|
|[Missouri](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/mo.py)|[📃](scrapers/mo.md)|[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|html|
|[Montana](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/mt.py)||[ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel, html|
|[Nebraska](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ne.py)||[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[New Jersey](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/nj.py)||[Dilcia19](https://github.com/Dilcia19), [palewire](https://github.com/palewire), [zstumgoren](https://github.com/zstumgoren)|html|
|[New Mexico](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/nm.py)||[chriszs](https://github.com/chriszs)|pdf|
|[New York](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ny.py)|[📃](scrapers/ny.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel, historical|
|[Ohio](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/oh.py)||[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Oklahoma](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ok.py)|[📃](scrapers/ok.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Oregon](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/or.py)|[📃](scrapers/or.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel, historical|
|[Rhode Island](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ri.py)||[Dilcia19](https://github.com/Dilcia19), [chriszs](https://github.com/chriszs), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel|
|[South Dakota](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/sd.py)||[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|html|
|[Texas](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/tx.py)|[📃](scrapers/tx.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212)|excel, historical, html|
|[Utah](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ut.py)|[📃](scrapers/ut.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Vermont](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/vt.py)|[📃](scrapers/vt.md)|[zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Virginia](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/va.py)|[📃](scrapers/va.md)|[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|csv, html|
|[Washington](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/wa.py)||[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Wisconsin](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/wi.py)|[📃](scrapers/wi.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|html|
|[District of Columbia](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/dc.py)|[📃](scrapers/dc.md)|[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|html|


## To do

These 21 areas need a scraper:

- Arkansas
- Colorado
- Hawaii
- Massachusetts
- Michigan
- Minnesota
- Mississippi
- Nevada
- New Hampshire
- North Carolina
- North Dakota
- Pennsylvania
- South Carolina
- Tennessee
- West Virginia
- Wyoming
- American Samoa
- Guam
- Northern Mariana Islands
- Puerto Rico
- Virgin Islands
